[][src]Struct ac_ffmpeg::codec::video::frame::VideoFrameMut

pub struct VideoFrameMut { /* fields omitted */ }

A video frame with mutable data.

Implementations

impl VideoFrameMut[src]

pub fn black(pixel_format: PixelFormat, width: usize, height: usize) -> Self[src]

Create a black video frame. The time base of the frame will be in microseconds.

pub fn pixel_format(&self) -> PixelFormat[src]

Get frame pixel format.

pub fn width(&self) -> usize[src]

Get frame width.

pub fn height(&self) -> usize[src]

Get frame height.

pub fn time_base(&self) -> TimeBase[src]

Get frame time base.

pub fn with_time_base(self, time_base: TimeBase) -> Self[src]

Set frame time base. (This will rescale the current timestamp into a given time base.)

pub fn pts(&self) -> Timestamp[src]

Get presentation timestamp.

pub fn with_pts(self, pts: Timestamp) -> Self[src]

Set presentation timestamp.

pub fn planes(&self) -> Planes<'_>[src]

Get picture planes.

pub fn planes_mut(&mut self) -> PlanesMut<'_>[src]

Get mutable picture planes.

pub fn freeze(self) -> VideoFrame[src]

Make the frame immutable.