[−][src]Struct ac_ffmpeg::format::demuxer::DemuxerWithCodecParameters
Demuxer with information about individual streams.
Implementations
impl<T> DemuxerWithCodecParameters<T>[src]
pub fn codec_parameters(&self) -> &[CodecParameters][src]
Get codec parameters.
pub fn deconstruct(self) -> (Demuxer<T>, Vec<CodecParameters>)[src]
Deconstruct this object into a plain demuxer and codec parameters.
Methods from Deref<Target = Demuxer<T>>
pub fn set_option<V>(&mut self, name: &str, value: V) -> Result<(), Error> where
V: ToString, [src]
V: ToString,
Set an option.
pub fn take(&mut self) -> Result<Option<Packet>, Error>[src]
Take the next packet from the demuxer or None on EOF. The pts and dts fields of the returned packet will be in microseconds.
pub fn io(&self) -> &IO<T>[src]
Get reference to the underlying IO.
pub fn io_mut(&mut self) -> &mut IO<T>[src]
Get mutable reference to the underlying IO.