[−][src]Struct ac_ffmpeg::packet::Packet
Packet with immutable data.
Implementations
impl Packet[src]
pub fn stream_index(&self) -> usize[src]
Get stream index.
pub fn with_stream_index(self, index: usize) -> Packet[src]
Set stream index.
pub fn time_base(&self) -> TimeBase[src]
Get packet time base.
pub fn with_time_base(self, time_base: TimeBase) -> Self[src]
Set packet time base. (This will rescale the current timestamps into a given time base.)
pub fn pts(&self) -> Timestamp[src]
Get packet presentation timestamp.
pub fn with_pts(self, pts: Timestamp) -> Self[src]
Set packet presentation timestamp.
pub fn dts(&self) -> Timestamp[src]
Get packet decoding timestamp.
pub fn with_dts(self, dts: Timestamp) -> Self[src]
Set packet decoding timestamp.
pub fn is_key(&self) -> bool[src]
Check if the key flag is set.
pub fn data(&self) -> &[u8][src]
Get packet data.
pub fn into_mut(self) -> PacketMut[src]
Make this packet mutable. If there are no other references to the packet data, the mutable packet will be created without copying the data.